"use strict";

exports.__esModule = true;
exports.isRpx = isRpx;
exports.calcRpx = calcRpx;
exports.getRpx = getRpx;
exports.setRpx = setRpx;
exports.setDecimalPixelTransformer = setDecimalPixelTransformer;
exports.convertUnit = convertUnit;
var RPX_REG = /^[-+]?\d*\.?\d+rpx/g;
var GLOBAL_RPX_UNIT = '__global_rem_unit__'; // Compatible to old variable.

var global = typeof window === 'object' ? window : typeof global === 'object' ? global : {}; // Dedault decimal transformer.

var decimalPixelTransformer = function decimalPixelTransformer(rpx) {
  return parseFloat(rpx) * getRpx() + 'px';
}; // Default 1 rpx to 1 px


if (getRpx() === undefined) {
  setRpx(1);
}
/**
 * Is string contains rpx
 * note: rpx is an alias to rpx
 * @param {String} str
 * @returns {Boolean}
 */


function isRpx(str) {
  return typeof str === 'string' && RPX_REG.test(str);
}
/**
 * Calculate rpx to pixels: '1.2rpx' => 1.2 * rpx
 * @param {String} str
 * @returns {String}
 */


function calcRpx(str) {
  return str.replace(RPX_REG, decimalPixelTransformer);
}

function getRpx() {
  return global[GLOBAL_RPX_UNIT];
}

function setRpx(rpx) {
  global[GLOBAL_RPX_UNIT] = rpx;
}
/**
 * Set a function to transform unit of pixel,
 * default to passthrough.
 * @param {Function} transformer function
 */


function setDecimalPixelTransformer(transformer) {
  decimalPixelTransformer = transformer;
}

var cache = Object.create(null);
/**
 * Convert rpx.
 * @param value
 * @param prop
 * @return {String} Transformed value.
 */

function convertUnit(value, prop) {
  var cacheKey = prop + "-" + value;
  var hit = cache[cacheKey];

  if (hit) {
    return hit;
  } else {
    value = value + '';
    return cache[cacheKey] = isRpx(value) ? calcRpx(value) : value;
  }
}